"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const cmc_error_code_enum_1 = require("../enums/cmc-error-code.enum");
const cmc_apikey_disabled_error_1 = require("../errors/cmc-apikey-disabled.error");
const cmc_apikey_required_error_1 = require("../errors/cmc-apikey-required.error");
const cmc_invalid_error_1 = require("../errors/cmc-invalid.error");
const cmc_missing_error_1 = require("../errors/cmc-missing.error");
const cmc_payment_expired_error_1 = require("../errors/cmc-payment-expired.error");
const cmc_payment_required_error_1 = require("../errors/cmc-payment-required.error");
const cmc_plan_unauthorize_error_1 = require("../errors/cmc-plan-unauthorize.error");
const cmc_rate_limit_daily_error_1 = require("../errors/cmc-rate-limit-daily.error");
const cmc_rate_limit_ip_error_1 = require("../errors/cmc-rate-limit-ip.error");
const cmc_rate_limit_minute_error_1 = require("../errors/cmc-rate-limit-minute.error");
const cmc_rate_limit_monthly_error_1 = require("../errors/cmc-rate-limit-monthly.error");
const cmc_request_error_1 = require("../errors/cmc-request.error");
class Client {
    constructor() {
        if (!this.baseURL)
            this.baseURL = Client.BaseURL.Pro;
    }
    async req(endpoint, query, headers) {
        var _a, _b;
        const request = await fetch(this.genUri(endpoint, query), {
            method: "GET",
            headers: this.genHeaders(headers),
        });
        const result = await request.json();
        const status = ((_a = result === null || result === void 0 ? void 0 : result.data) === null || _a === void 0 ? void 0 : _a.status) || (result === null || result === void 0 ? void 0 : result.status);
        const data = (((_b = result === null || result === void 0 ? void 0 : result.data) === null || _b === void 0 ? void 0 : _b.data) || (result === null || result === void 0 ? void 0 : result.data));
        this.status = status;
        if (status.error_code > 0)
            throw this.error(status);
        return data;
    }
    setApiKey(apiKey) {
        this.apikey = apiKey;
        return this;
    }
    setBaseUrl(baseUrl) {
        this.baseURL = baseUrl;
        return this;
    }
    commaSeparate(array) {
        return Array.isArray(array) ? array.join(",") : String(array);
    }
    sandbox() {
        this.apikey = Client.SandboxApikey;
        this.baseURL = Client.BaseURL.Sandbox;
        return this;
    }
    genUri(endpoint, query) {
        const uri = new URL(endpoint, this.baseURL);
        if (query) {
            for (const key of Object.keys(query))
                if (query[key] && query[key] !== "undefined" && query[key] !== "null") {
                    if (Array.isArray(query[key])) {
                        uri.searchParams.append(key, this.commaSeparate(query[key]));
                    }
                    else {
                        uri.searchParams.append(key, String(query === null || query === void 0 ? void 0 : query[key]));
                    }
                }
        }
        return uri;
    }
    genHeaders(additionHeaders) {
        const headers = new Headers();
        headers.append("X-CMC_PRO_API_KEY", this.apikey);
        if (additionHeaders)
            for (const key of Object.keys(additionHeaders))
                headers.append(key, additionHeaders[key]);
        return headers;
    }
    error(status, data) {
        switch (status.error_code) {
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyInvalid:
                return new cmc_invalid_error_1.CmcInvalidError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyMissing:
                return new cmc_missing_error_1.CmcMissingError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyPlanRequiresPayment:
                return new cmc_payment_required_error_1.CmcPaymentRequiredError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyPlanPaymentExpired:
                return new cmc_payment_expired_error_1.CmcPaymentExpiredError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyRequired:
                return new cmc_apikey_required_error_1.CmcApikeyRequiredError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyPlanNotAuthorized:
                return new cmc_plan_unauthorize_error_1.CmcPlanUnauthorizeError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyDisable:
                return new cmc_apikey_disabled_error_1.CmcApikeyDisabledError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyPlanMinuteRateLimitReached:
                return new cmc_rate_limit_minute_error_1.CmcMinuteRateLimitError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyPlanDailyRateLimitReached:
                return new cmc_rate_limit_daily_error_1.CmcDailyRateLimitError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.ApikeyPlanMonthlyRateLimitReached:
                return new cmc_rate_limit_monthly_error_1.CmcMonthlyRateLimitError(status, data);
            case cmc_error_code_enum_1.CmcErrorCode.IpRateLimitReached:
                return new cmc_rate_limit_ip_error_1.CmcIpRateLimitError(status, data);
        }
        return new cmc_request_error_1.CmcRequestError(status, data);
    }
}
exports.Client = Client;
Client.SandboxApikey = "b54bcf4d-1bca-4e8e-9a24-22ff2c3d462c";
Client.BaseURL = {
    Sandbox: "https://sandbox-api.coinmarketcap.com",
    Pro: "https://pro-api.coinmarketcap.com",
};
//# sourceMappingURL=client.js.map