import { Repository } from "../core/repository";
import type { Interval, Pair } from "../types/common.type";
import type { AuxiliaryList, AuxiliaryListing, AuxiliaryListingHistory, AuxiliaryMarketPair, AuxiliaryMetadata, AuxiliaryQuotesHistorical, AuxiliaryQuotesLatest, CryptoConvert, CryptoId, CryptoIdOnly, CryptoIdSingleOnly, CryptoIdSymbolOnly, ListingCryptoType, ListingFilter, ListingHistorySort, ListingSort, ListingSortDir, ListingStatus, ListingTag, ListSort, MarketPairCategory, MarketPairFeeType, MarketPairSort, Matched, PerformanceStatsTimePeriod } from "../types/crypto.options";
import type { Quote } from "../responses/common.response";
import type { CryptoAirdropResponse, CryptoAirdropsResponse, CryptoCategoriesResponse, CryptoCategoryResponse, CryptoGrainersLosersResponse, CryptoIdMapResponse, CryptoListingHistoricalQuoteValue, CryptoListingHistoricalResponse, CryptoListingLatestResponse, CryptoListingNewResponse, CryptoMarketPairsQuoteValue, CryptoMarketPairsResponse, CryptoMetadataV2Response, CryptoMostVisitedResponse, CryptoOhlcvHistoricalQuoteValue, CryptoOhlcvHistoricalResponse, CryptoOhlcvLatestQuoteValue, CryptoOhlcvLatestResponse, CryptoPricePerformancePeriodResponse, CryptoPricePerformanceQuoteValue, CryptoPricePerformanceStatsResponse, CryptoQuotesHistoricalQuoteValue, CryptoQuotesHistoricalResponse, CryptoQuotesLatestResponse, CryptoTrendingLatestResponse } from "../responses/crypto.response";
export declare class CryptoRepository extends Repository {
    private endpoints;
    list<TResponse = CryptoIdMapResponse[]>(listingStatus?: ListingStatus, sort?: ListSort, limit?: number, offset?: number, symbol?: string[] | number[], aux?: AuxiliaryList): Promise<TResponse>;
    metadata<TKey extends string = string, TValue = CryptoMetadataV2Response & CryptoMetadataV2Response[], TResponse = Pair<TKey, TValue>>(id: CryptoId, aux?: AuxiliaryMetadata, skipInvalid?: boolean): Promise<TResponse>;
    listing<TQuoteKey extends string = "USD", TQuoteValue extends object = Quote, TResponse = CryptoListingLatestResponse<TQuoteKey, TQuoteValue>[]>(limit?: number, offset?: number, type?: ListingCryptoType, sort?: ListingSort, sortDir?: ListingSortDir, tag?: ListingTag, filters?: ListingFilter, convert?: CryptoConvert, aux?: AuxiliaryListing): Promise<TResponse>;
    listingNew<TQuoteKey extends string = "USD", TQuoteValue extends object = Quote, TResponse = CryptoListingNewResponse<TQuoteKey, TQuoteValue>[]>(limit?: number, offset?: number, sortDir?: ListingSortDir, convert?: CryptoConvert): Promise<TResponse>;
    listingHistory<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoListingHistoricalQuoteValue, TResponse = CryptoListingHistoricalResponse<TQuoteKey, TQuoteValue>[]>(date: Date, limit?: number, offset?: number, sort?: ListingHistorySort, sortDir?: ListingSortDir, type?: ListingCryptoType, convert?: CryptoConvert, aux?: AuxiliaryListingHistory): Promise<TResponse>;
    quotes<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = Quote, TValue = CryptoQuotesLatestResponse<TQuoteKey, TQuoteValue> & CryptoQuotesLatestResponse<TQuoteKey, TQuoteValue>[], TResponse = Pair<TKey, TValue>>(id: CryptoIdOnly, convert?: CryptoConvert, skipInvalid?: boolean, aux?: AuxiliaryQuotesLatest): Promise<TResponse>;
    quotesHistory<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoQuotesHistoricalQuoteValue, TResponse = Pair<TKey, CryptoQuotesHistoricalResponse<TQuoteKey, TQuoteValue>>>(id: CryptoIdSymbolOnly, timeStart?: Date, timeEnd?: Date, interval?: Interval, count?: number, version?: "v2" | "v3", convert?: CryptoConvert, aux?: AuxiliaryQuotesHistorical, skipInvalid?: boolean): Promise<TResponse>;
    marketPairs<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoMarketPairsQuoteValue, TResponse = CryptoMarketPairsResponse<TQuoteKey, TQuoteValue>>(id: CryptoIdSingleOnly, matched?: Matched, limit?: number, offset?: number, category?: MarketPairCategory, feeType?: MarketPairFeeType, sort?: MarketPairSort, convert?: CryptoConvert, aux?: AuxiliaryMarketPair): Promise<TResponse>;
    ohlcv<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoOhlcvLatestQuoteValue, TResponse = Pair<TKey, CryptoOhlcvLatestResponse<TQuoteKey, TQuoteValue>>>(id: CryptoIdSymbolOnly, convert?: CryptoConvert, skipInvalid?: boolean): Promise<TResponse>;
    ohlcvHistory<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoOhlcvHistoricalQuoteValue, TResponse = Pair<TKey, CryptoOhlcvHistoricalResponse<TQuoteKey, TQuoteValue>>>(id: CryptoIdOnly, timeStart?: Date, timeEnd?: Date, timePeriod?: "daily" | "hourly", interval?: Interval, count?: number, convert?: CryptoConvert, skipInvalid?: boolean): Promise<TResponse>;
    performance<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoPricePerformanceQuoteValue, TResponse = Pair<TKey, CryptoPricePerformanceStatsResponse<TQuoteKey, TQuoteValue> & CryptoPricePerformancePeriodResponse<TQuoteKey, TQuoteValue>>>(id: CryptoIdOnly, timePeriod?: PerformanceStatsTimePeriod, convert?: CryptoConvert, skipInvalid?: boolean): Promise<TResponse>;
    category<TQuoteKey extends string = "USD", TResponse = CryptoCategoryResponse<TQuoteKey>>(id: string, limit?: number, offset?: number, convert?: CryptoConvert): Promise<TResponse>;
    categories<TResponse = CryptoCategoriesResponse[]>(limit?: number, offset?: number, id?: CryptoIdOnly): Promise<TResponse>;
    airdrop<TResponse = CryptoAirdropResponse>(id: string): Promise<TResponse>;
    airdrops<TResponse = CryptoAirdropsResponse>(status?: "ended" | "ongoing" | "upcoming", limit?: number, offset?: number, id?: CryptoIdSingleOnly): Promise<TResponse>;
    trending<TQuoteKey extends string = "USD", TResponse = CryptoTrendingLatestResponse<TQuoteKey>>(timePeriod?: "24h" | "30d" | "7d", limit?: number, offset?: number, convert?: CryptoConvert): Promise<TResponse>;
    mostVisited<TQuoteKey extends string = "USD", TResponse = CryptoMostVisitedResponse<TQuoteKey>>(timePeriod?: "24h" | "30d" | "7d", limit?: number, offset?: number, convert?: CryptoConvert): Promise<TResponse>;
    gainersLosers<TQuoteKey extends string = "USD", TResponse = CryptoGrainersLosersResponse<TQuoteKey>>(timePeriod?: "1h" | "24h" | "30d" | "7d", limit?: number, offset?: number, convert?: CryptoConvert, sortDir?: "asc" | "desc", sort?: "percent_change_24h"): Promise<TResponse>;
}
