"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CryptoRepository = void 0;
const endpoints_1 = require("../core/endpoints");
const repository_1 = require("../core/repository");
const date_util_1 = require("../utils/date.util");
class CryptoRepository extends repository_1.Repository {
    constructor() {
        super(...arguments);
        this.endpoints = endpoints_1.default.crypto;
    }
    async list(listingStatus = "active", sort = "id", limit, offset = 1, symbol, aux = ["platform", "first_historical_data", "last_historical_data", "is_active"]) {
        return await this.cmc.client.req(this.endpoints.map, {
            limit: limit,
            sort: sort,
            symbol: symbol,
            start: offset,
            listing_status: listingStatus,
            aux: aux,
        });
    }
    async metadata(id, aux = ["urls", "logo", "description", "tags", "platform", "date_added", "notice"], skipInvalid = false) {
        return await this.cmc.client.req(this.endpoints.metadata, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: this.cmc.client.commaSeparate(id.id) })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: this.cmc.client.commaSeparate(id.slug) })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: this.cmc.client.commaSeparate(id.symbol) })), ((id === null || id === void 0 ? void 0 : id.contract) && { address: id.contract })), { skip_invalid: skipInvalid, aux: aux }));
    }
    async listing(limit = 100, offset = 1, type = "all", sort = "market_cap", sortDir, tag = "all", filters, convert, aux = [
        "num_market_pairs",
        "cmc_rank",
        "date_added",
        "tags",
        "platform",
        "max_supply",
        "circulating_supply",
        "total_supply",
    ]) {
        return await this.cmc.client.req(this.endpoints.listings, Object.assign({ limit: limit, start: offset, cryptocurrency_type: type, sort: sort, sort_dir: sortDir, tag: tag, aux: aux, price_min: filters === null || filters === void 0 ? void 0 : filters.priceMin, price_max: filters === null || filters === void 0 ? void 0 : filters.priceMax, market_cap_min: filters === null || filters === void 0 ? void 0 : filters.marketCapMin, market_cap_max: filters === null || filters === void 0 ? void 0 : filters.marketCapMax, volume_24h_min: filters === null || filters === void 0 ? void 0 : filters.volume24hMin, volume_24h_max: filters === null || filters === void 0 ? void 0 : filters.volume24hMax, circulating_supply_min: filters === null || filters === void 0 ? void 0 : filters.circulatingSupplyMin, circulating_supply_max: filters === null || filters === void 0 ? void 0 : filters.circulatingsupplyMax, percent_change_24h_min: filters === null || filters === void 0 ? void 0 : filters.percentChange24hMin, percent_change_24h_max: filters === null || filters === void 0 ? void 0 : filters.percentChange24hMax }, (Number.isInteger(convert) ? { convert_id: convert } : { convert })));
    }
    async listingNew(limit = 100, offset = 1, sortDir, convert) {
        return await this.cmc.client.req(this.endpoints.listingsNew, Object.assign({ limit: limit, start: offset, sort_dir: sortDir }, (Number.isInteger(convert) ? { convert_id: convert } : { convert })));
    }
    async listingHistory(date, limit = 100, offset = 1, sort = "cmc_rank", sortDir, type = "all", convert, aux = [
        "platform",
        "tags",
        "date_added",
        "circulating_supply",
        "total_supply",
        "max_supply",
        "cmc_rank",
        "num_market_pairs",
    ]) {
        return await this.cmc.client.req(this.endpoints.listingsHistorical, Object.assign({ limit: limit, start: offset, date: (0, date_util_1.dateToUnix)(date), sort: sort, sort_dir: sortDir, cryptocurrency_type: type, aux: aux }, (Number.isInteger(convert) ? { convert_id: convert } : { convert })));
    }
    async quotes(id, convert, skipInvalid = true, aux = [
        "num_market_pairs",
        "cmc_rank",
        "date_added",
        "tags",
        "platform",
        "max_supply",
        "circulating_supply",
        "total_supply",
        "is_active",
        "is_fiat",
    ]) {
        return await this.cmc.client.req(this.endpoints.quotes, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: this.cmc.client.commaSeparate(id.id) })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: this.cmc.client.commaSeparate(id.slug) })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: this.cmc.client.commaSeparate(id.symbol) })), (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { skip_invalid: skipInvalid, aux: aux }));
    }
    async quotesHistory(id, timeStart, timeEnd, interval = "5m", count = 10, version = "v3", convert, aux = [
        "price",
        "volume",
        "market_cap",
        "circulating_supply",
        "total_supply",
        "quote_timestamp",
        "is_active",
        "is_fiat",
    ], skipInvalid = true) {
        const endpoint = version == "v2" ? this.endpoints.quotesHistorical : this.endpoints.quotesHistoricalV3;
        return await this.cmc.client.req(endpoint, Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: this.cmc.client.commaSeparate(id.id) })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: this.cmc.client.commaSeparate(id.symbol) })), (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { count: count, interval: interval, time_start: (0, date_util_1.dateToUnix)(timeStart), time_end: (0, date_util_1.dateToUnix)(timeEnd), skip_invalid: skipInvalid, aux: aux }));
    }
    async marketPairs(id, matched, limit = 100, offset = 1, category = "all", feeType = "all", sort = "volume_24h_strict", convert, aux = ["num_market_pairs", "category", "fee_type"]) {
        return await this.cmc.client.req(this.endpoints.marketPairs, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: this.cmc.client.commaSeparate(id.id) })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: this.cmc.client.commaSeparate(id.slug) })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: this.cmc.client.commaSeparate(id.symbol) })), ((matched === null || matched === void 0 ? void 0 : matched.id) && { matched_id: this.cmc.client.commaSeparate(matched.id) })), ((matched === null || matched === void 0 ? void 0 : matched.symbol) && { matched_symbol: this.cmc.client.commaSeparate(matched.symbol) })), (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { limit: limit, start: offset, category: category, fee_type: feeType, sort: sort, aux: aux }));
    }
    async ohlcv(id, convert, skipInvalid = true) {
        return await this.cmc.client.req(this.endpoints.ohlcv, Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: this.cmc.client.commaSeparate(id.id) })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: this.cmc.client.commaSeparate(id.symbol) })), (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { skip_invalid: skipInvalid }));
    }
    async ohlcvHistory(id, timeStart, timeEnd, timePeriod = "daily", interval = "daily", count = 10, convert, skipInvalid = true) {
        return await this.cmc.client.req(this.endpoints.ohlcvHistorical, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: this.cmc.client.commaSeparate(id.id) })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: this.cmc.client.commaSeparate(id.slug) })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: this.cmc.client.commaSeparate(id.symbol) })), (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { count: count, interval: interval, time_period: timePeriod, time_start: (0, date_util_1.dateToUnix)(timeStart), time_end: (0, date_util_1.dateToUnix)(timeEnd), skip_invalid: skipInvalid }));
    }
    async performance(id, timePeriod = "all_time", convert, skipInvalid = true) {
        return await this.cmc.client.req(this.endpoints.performance, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: id.symbol })), (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { time_period: timePeriod, skip_invalid: skipInvalid }));
    }
    async category(id, limit = 100, offset = 1, convert) {
        return await this.cmc.client.req(this.endpoints.category, Object.assign(Object.assign({}, (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { limit: limit, start: offset, id: id }));
    }
    async categories(limit, offset = 1, id) {
        return await this.cmc.client.req(this.endpoints.categories, Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: id.symbol })), { limit: limit, start: offset }));
    }
    async airdrop(id) {
        return await this.cmc.client.req(this.endpoints.airdrop, { id });
    }
    async airdrops(status = "upcoming", limit = 100, offset = 1, id) {
        return await this.cmc.client.req(this.endpoints.airdrops, Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), ((id === null || id === void 0 ? void 0 : id.symbol) && { symbol: id.symbol })), { status: status.toUpperCase(), limit: limit, start: offset }));
    }
    async trending(timePeriod = "24h", limit = 100, offset = 1, convert) {
        return await this.cmc.client.req(this.endpoints.trending, Object.assign(Object.assign({}, (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { time_period: timePeriod, limit: limit, start: offset }));
    }
    async mostVisited(timePeriod = "24h", limit = 100, offset = 1, convert) {
        return await this.cmc.client.req(this.endpoints.mostVisited, Object.assign(Object.assign({}, (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { time_period: timePeriod, limit: limit, start: offset }));
    }
    async gainersLosers(timePeriod = "24h", limit = 100, offset = 1, convert, sortDir, sort = "percent_change_24h") {
        return await this.cmc.client.req(this.endpoints.gainersLosers, Object.assign(Object.assign({}, (Number.isInteger(convert) ? { convert_id: convert } : { convert })), { time_period: timePeriod, limit: limit, start: offset, sort: sort, sort_dir: sortDir }));
    }
}
exports.CryptoRepository = CryptoRepository;
//# sourceMappingURL=crypto.repository.js.map