import type { Interval, Pair, Timestamp, UnixEpoch } from "../types/common.type";
import type { PerformanceStatsTimePeriodOnly } from "../types/crypto.options";
import type { ContractAddress, Platform, Quote, QuoteMap, Tags, Urls } from "./common.response";
export interface CryptoIdMapResponse {
    id: number;
    rank: number;
    name: string;
    symbol: string;
    slug: string;
    is_active: number;
    status: "active" | "inactive" | "untracked";
    first_historical_data: Timestamp;
    last_historical_data: Timestamp;
    platform: Platform | null;
}
export interface CryptoMetadataV2Response {
    id: number;
    name: string;
    symbol: string;
    category: "coin" | "token";
    slug: string;
    logo: string;
    description: string | null;
    date_added: Timestamp;
    date_launched: Timestamp;
    subreddit: string;
    notice: string | null;
    tags: string[];
    tag_names: string[];
    tag_groups: string[];
    urls: Urls;
    platform?: Platform;
    twitter_username: string;
    is_hidden: number;
    contract_address: ContractAddress[];
    self_reported_circulating_supply: number | null;
    self_reported_tags: string[] | null;
    self_reported_market_cap: number | null;
    infinite_supply: boolean;
    status: "active" | "inactive" | "untracked";
}
export interface CryptoListingLatestResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = Quote> {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    cmc_rank: number;
    num_market_pairs: number;
    circulating_supply: number | null;
    total_supply: number | null;
    market_cap_by_total_supply?: number | null;
    max_supply: number | null;
    infinite_supply: boolean;
    last_updated: Timestamp;
    date_added: Timestamp;
    tags: string[];
    self_reported_circulating_supply: number | null;
    self_reported_market_cap: number | null;
    tvl_ratio: number | null;
    platform: Platform | null;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export interface CryptoListingNewResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = Quote> {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    cmc_rank: number;
    num_market_pairs: number;
    circulating_supply: number;
    total_supply: number;
    market_cap_by_total_supply?: number;
    max_supply: number;
    last_updated: Timestamp;
    date_added: Timestamp;
    tags: string[];
    platform: Platform | null;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export type CryptoListingHistoricalQuoteValue = Pick<Quote, "price" | "volume_24h" | "market_cap" | "percent_change_1h" | "percent_change_24h" | "percent_change_7d" | "last_updated">;
export interface CryptoListingHistoricalResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoListingHistoricalQuoteValue> {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    cmc_rank: number;
    num_market_pairs: number;
    circulating_supply: number;
    total_supply: number;
    max_supply: number;
    last_updated: Timestamp;
    date_added: Timestamp;
    tags: string[];
    platform: Platform | null;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export interface CryptoQuotesLatestResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = Quote> {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    is_active: number;
    is_fiat: number;
    cmc_rank: number;
    num_market_pairs: number;
    circulating_supply: number;
    total_supply: number;
    market_cap_by_total_supply: number;
    max_supply: number;
    date_added: Timestamp;
    tags: Tags[];
    platform: Platform | null;
    last_updated: Timestamp;
    self_reported_circulating_supply: number;
    self_reported_market_cap: number;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export interface CryptoQuotesHistoricalQuoteValue extends Pick<Quote, "price" | "volume_24h" | "market_cap"> {
    circulating_supply: number | null;
    total_supply: number | null;
    timestamp: Timestamp;
}
export interface CryptoQuotesHistoricalResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoQuotesHistoricalQuoteValue> {
    id: number;
    name: string;
    symbol: string;
    is_active: number;
    is_fiat: number | null;
    quotes: {
        timestamp: Timestamp;
        search_interval?: Interval;
        quote: QuoteMap<TQuoteKey, TQuoteValue>;
    }[];
}
export interface CryptoMarketPairExchangeResponse {
    id: number;
    slug: string;
    name: string;
    notice?: string | null;
}
export interface CryptoMarketPairMarkResponse {
    currency_id: number;
    currency_name?: string;
    currency_symbol: string;
    currency_slug?: string;
    exchange_symbol: string;
    currency_type: "cryptocurrency" | "fiat";
}
export interface CryptoMarketPairExchangeReportedQuoteResponse {
    price: number;
    volume_24h_base: number;
    volume_24h_quote: number;
    last_updated: Timestamp;
    effective_liquidity?: number;
    market_score?: number;
    market_reputation?: number;
}
export interface CryptoMarketPairResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = Pick<Quote, "price" | "price_quote" | "volume_24h" | "last_updated">> {
    market_id: number;
    market_pair: string;
    market_url?: string;
    category: "spot" | "derivatives" | "otc";
    fee_type: "percentage" | "no-fees" | "transactional-mining" | "unknown";
    exchange: CryptoMarketPairExchangeResponse;
    market_pair_base: CryptoMarketPairMarkResponse;
    market_pair_quote: CryptoMarketPairMarkResponse;
    quote: QuoteMap<TQuoteKey, TQuoteValue> & {
        exchange_reported: CryptoMarketPairExchangeReportedQuoteResponse;
    };
}
export type CryptoMarketPairsQuoteValue = Pick<Quote, "price" | "price_quote" | "volume_24h" | "last_updated">;
export interface CryptoMarketPairsResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoMarketPairsQuoteValue> {
    id: number;
    symbol: string;
    name: string;
    num_market_pairs: number;
    market_pairs: CryptoMarketPairResponse<TQuoteKey, TQuoteValue>[];
}
export interface CryptoOhlcvLatestQuoteValue extends Pick<Quote, "last_updated"> {
    open: number;
    high: number;
    low: number;
    close: number;
    volume: number;
    last_updated: Timestamp;
}
export interface CryptoOhlcvLatestResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoOhlcvLatestQuoteValue> {
    id: number;
    name: string;
    symbol: string;
    last_updated: Timestamp;
    time_open: Timestamp;
    time_high: Timestamp;
    time_low: Timestamp;
    time_close: Timestamp | null;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export interface CryptoOhlcvHistoricalQuoteValue extends Pick<Quote, "last_updated" | "market_cap"> {
    open: number;
    high: number;
    low: number;
    close: number;
    volume: number;
    timestamp: Timestamp;
}
export interface CryptoOhlcvHistoricalResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoOhlcvHistoricalQuoteValue> {
    id: number;
    name: string;
    symbol: string;
    quotes: Array<{
        time_open: Timestamp;
        time_close: Timestamp;
        time_high: Timestamp;
        time_low: Timestamp;
        quote: QuoteMap<TQuoteKey, TQuoteValue>;
    }>;
}
export interface CryptoPricePerformanceQuoteValue {
    open: number;
    high: number;
    low: number;
    close: number;
    percent_change: number;
    price_change: number;
    open_timestamp: Timestamp;
    high_timestamp: Timestamp;
    low_timestamp: Timestamp;
    close_timestamp: Timestamp;
}
export type CryptoPricePerformancePeriodResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoPricePerformanceQuoteValue> = {
    open_timestamp: Timestamp;
    close_timestamp: Timestamp;
    high_timestamp: Timestamp | null;
    low_timestamp: Timestamp | null;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
};
export type CryptoPricePerformanceStatsResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CryptoPricePerformanceQuoteValue> = {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    last_updated: Timestamp;
    periods: Pair<PerformanceStatsTimePeriodOnly, CryptoPricePerformancePeriodResponse<TQuoteKey, TQuoteValue>>;
};
export interface CryptoCategoryCoin<TQuoteKey extends string = "USD"> {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    cmc_rank: number;
    num_market_pairs: number;
    circulating_supply: number;
    total_supply: number;
    market_cap_by_total_supply?: number;
    max_supply: number;
    last_updated: Timestamp;
    date_added: Timestamp;
    tags: string[];
    platform: Platform | null;
    quote: QuoteMap<TQuoteKey, Pick<Quote, "price" | "volume_24h" | "percent_change_1h" | "percent_change_24h" | "percent_change_7d" | "market_cap" | "last_updated"> & Partial<Pick<Quote, "volume_24h_reported" | "volume_7d" | "volume_7d_reported" | "volume_30d" | "volume_30d_reported">>>;
}
export interface CryptoCategoryResponse<TQuoteKey extends string = "USD"> {
    id: number;
    name: string;
    title: string;
    description: string;
    num_tokens: number;
    avg_price_change: number;
    market_cap: number;
    market_cap_change: number;
    volume: number;
    volume_change: number;
    last_updated: UnixEpoch;
    coins: Array<CryptoCategoryCoin<TQuoteKey>>;
}
export interface CryptoCategoriesResponse {
    id: number;
    name: string;
    title: string;
    description: string;
    num_tokens: number;
    avg_price_change: number;
    market_cap: number;
    market_cap_change: number;
    volume: number;
    volume_change: number;
    last_updated: Timestamp;
}
export interface CryptoAirdropCoin {
    id: number;
    name: string;
    symbol: string;
    slug: string;
}
export interface CryptoAirdropResponse {
    id: string;
    project_name: string;
    description: string;
    status: string;
    coin: CryptoAirdropCoin;
    start_date: Timestamp;
    end_date: Timestamp;
    total_prize: number;
    winner_count: number;
    link: string;
}
export type CryptoAirdropsResponse = CryptoAirdropResponse[];
export interface CryptoTrendingResponse<TQuoteKey extends string = "USD"> {
    id: number;
    name: string;
    symbol: string;
    slug: string;
    cmc_rank: number;
    is_fiat: 0 | 1;
    self_reported_circulating_supply: number;
    self_reported_market_cap: number;
    is_active: 0 | 1;
    num_market_pairs: number;
    circulating_supply: number;
    total_supply: number;
    market_cap_by_total_supply?: number;
    max_supply: number;
    last_updated: Timestamp;
    date_added: Timestamp;
    tags: string[];
    platform: Platform | null;
    quote: QuoteMap<TQuoteKey, Pick<Quote, "price" | "volume_24h" | "percent_change_1h" | "percent_change_24h" | "percent_change_7d" | "market_cap" | "last_updated"> & Partial<Pick<Quote, "volume_24h_reported" | "volume_7d" | "volume_7d_reported" | "volume_30d" | "volume_30d_reported">>>;
}
export type CryptoTrendingLatestResponse<TQuoteKey extends string = "USD"> = Array<CryptoTrendingResponse<TQuoteKey> & {
    is_fiat: number;
    is_active: number;
    self_reported_circulating_supply: number | null;
    self_reported_market_cap: number | null;
}>;
export type CryptoMostVisitedResponse<TQuoteKey extends string = "USD"> = Array<CryptoTrendingResponse<TQuoteKey>>;
export type CryptoGrainersLosersResponse<TQuoteKey extends string = "USD"> = Array<CryptoTrendingResponse<TQuoteKey>>;
